@@ -4,47 +4,56 @@
  * See COPYING in top-level directory.
  */
 
+#ifndef _REENTRANT
 #define _REENTRANT
+#endif
 
-#include <unistd.h>
+#include "mpi_eztrace.h"
+
+#include <dlfcn.h>
+#include <eztrace-lib/eztrace.h>
+#include <mpi.h>
 #include <stdint.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <sys/time.h>
 #include <sys/timeb.h>
-#include <dlfcn.h>
-#include <string.h>
+#include <unistd.h>
+#include <eztrace-core/eztrace_attributes.h>
 
-#include "mpi.h"
-#include "mpi_eztrace.h"
-#include "mpi_ev_codes.h"
-#include "eztrace.h"
+/* defined in mpi_start.c */
+void _ezt_MPI_Start_request(MPI_Request* req);
 
-static void MPI_Startall_prolog(int count, void*req, size_t size) {
-  int i;
-    for (i = 0; i < count; i++)
-    /* we can't use &req[i] here since req may be an array of MPI_Request or MPI_Fint
-     * (which may have different size)
-     */
-        EZTRACE_EVENT_PACKED_1(EZTRACE_MPI_START, (app_ptr)((void*)req + (i*size)));
+static void MPI_Startall_prolog(int count,
+				void* req,
+				size_t size) {
+  for(int i=0; i<count; i++) {
+    uintptr_t ptr = ((uintptr_t)req) + size*i;
+    _ezt_MPI_Start_request((MPI_Request*)ptr);
+  }
 }
 
-static int MPI_Startall_core(int count, MPI_Request *req) {
+static int MPI_Startall_core(int count,
+			     MPI_Request* req) {
   return libMPI_Startall(count, req);
-
 }
 
-int MPI_Startall(int count, MPI_Request *req) {
+int MPI_Startall(int count,
+		 MPI_Request* req) {
   FUNCTION_ENTRY;
 
   MPI_Startall_prolog(count, req, sizeof(MPI_Request));
   int ret = MPI_Startall_core(count, req);
 
+  FUNCTION_EXIT;
   return ret;
 }
 
-void mpif_startall_(int*count, MPI_Fint *reqs, int*error) {
-  FUNCTION_ENTRY;
+void mpif_startall_(int* count,
+		    MPI_Fint* reqs,
+		    int* error) {
+  FUNCTION_ENTRY_("mpi_startall_");
   int i;
   ALLOCATE_ITEMS(MPI_Request, *count, c_req, p_req);
 
@@ -57,5 +66,5 @@ void mpif_startall_(int*count, MPI_Fint *reqs, int*error) {
   for (i = 0; i < *count; i++)
     reqs[i] = MPI_Request_c2f(p_req[i]);
 
-  FREE_ITEMS(*count, p_req);
+  FUNCTION_EXIT_("mpi_startall_");
 }
