@@ -30,9 +30,9 @@ void debug(char *fmt, ...) {
 }
 // end of debugging part
 
-#define SIZE (1024*8)
+#define SIZE (100)
 
-int res = 0;
+_Atomic int res = 0;
 
 omp_lock_t lock;
 
@@ -46,15 +46,14 @@ void task_function(int n) {
 }
 
 int main(void) {
-  int i;
-
   omp_init_lock(&lock);
+  omp_set_num_threads(4);
 
   int j;
-#pragma omp parallel
-  for (j = 0; j < 10; j++) {
+#pragma omp parallel for
+  for (j = 0; j < 10; j++) {    
     debug("loop %d\n", j);
-    for (i = 0; i < SIZE; i++) {
+    for (int i = 0; i < SIZE; i++) {
       if (j % 2) {
 #pragma omp task untied
         task_function(i);
